
[![Tests](https://github.com/hyperspy/exspy/actions/workflows/tests.yml/badge.svg)](https://github.com/hyperspy/exspy/actions/workflows/tests.yml)
[![Docs](https://readthedocs.org/projects/exspy/badge/?version=latest)](https://exspy.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/hyperspy/exspy/graph/badge.svg?token=X7T3LE121Q)](https://codecov.io/gh/hyperspy/exspy)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

**exSpy** is a Python package extending the functionality for multi-dimensional
data analysis provided by the [HyperSpy](https://hyperspy.org) library. It is
aimed at helping with the analysis of X-rays Energy Dispersive Spectroscopy (EDS)
and Electron Energy Loss Spectroscopy (EELS).

Go to the documentation for instructions on how to install exSpy and start an
analysis: [Read the docs](https://exspy.readthedocs.io).

Everyone is welcome to contribute. Please read our
[contributing guidelines](https://github.com/hyperspy/exspy/blob/main/CONTRIBUTING.rst) and get started!

Development of exSpy is documented in the
[changelog](https://github.com/hyperspy/exspy/blob/main/CHANGES.rst).
